==> swt4-gtk_4.16.0.orig.tar.xz: swt4-gtk-4.16.0/bundles/org.eclipse.swt/Readme.md <==
org.eclipse.swt
===============

Main plug-in for the SWT user interface library.

Setting the classpath:
----------------------

To compile this project, you need to set the classpath specific for your operating and windowing system.
For this, rename one of the following files to `.classpath`:

* .classpath_win32 - Windows
* .classpath_cocoa - Mac OS X
* .classpath_gtk - Linux and all Unix variants

Similar class paths renaming should be done for ./examples/org.eclipse.swt.snippets/

To see these files, you may have to remove the filter for ".* resources":
* In the Project Explorer: view menu > Customize View... > Filters
* In the Package Explorer: view menu > Filters...


Dependencies:
-------------

* **SWT Binaries**  
  You also need to clone the binary Git repository:
  https://git.eclipse.org/r/#/admin/projects/platform/eclipse.platform.swt.binaries  
  and import the project for your platform into your workspace.  
  
  Ensure that the fragment matching your windowingSystem.operatingSystem.cpuArchitecture  
  (e.g. org.eclipse.swt.gtk.linux.x86_64) is open in your workspace.  
  The fragments provide the platform-specific native libraries.

Using Assertions:
----------------
Assertions are added to the code. These don't run in production, but they do when:
* JUnits are ran, they turn on assertions by default.
* If you run a java run configuration and add '-ea' to the 'VM Arguments'

Assertions look like:

	assert expression ;
	assert expression : msg ;

See: https://docs.oracle.com/javase/8/docs/technotes/guides/language/assert.html

More Information:
-----------------

See the [Readme.md](../../Readme.md) in the main directory of the Git repository for this project to learn more about SWT development.

==> swt4-gtk_4.29.0.orig.tar.xz: swt4-gtk-4.29.0/bundles/org.eclipse.swt/Readme.md <==
org.eclipse.swt
===============

Main plug-in for the SWT user interface library.

Setting the classpath:
----------------------

To compile this project, you need to set the classpath specific for your operating and windowing system.
For this, rename one of the following files to `.classpath`:

* .classpath_win32 - Windows
* .classpath_cocoa - Mac OS X
* .classpath_gtk - Linux and all Unix variants

Similar class paths renaming should be done for ./examples/org.eclipse.swt.snippets/

To see these files, you may have to remove the filter for ".* resources":
* In the Project Explorer: view menu > Customize View... > Filters
* In the Package Explorer: view menu > Filters...


Dependencies:
-------------

* **SWT Binaries**  
  You also need to clone the binary Git repository:
  https://github.com/eclipse-platform/eclipse.platform.swt.binaries/ 
  and import the project for your platform into your workspace.  
  
  Ensure that the fragment matching your windowingSystem.operatingSystem.cpuArchitecture  
  (e.g. org.eclipse.swt.gtk.linux.x86_64) is open in your workspace.  
  The fragments provide the platform-specific native libraries.

Using Assertions:
----------------
Assertions are added to the code. These don't run in production, but they do when:
* JUnits are ran, they turn on assertions by default.
* If you run a java run configuration and add '-ea' to the 'VM Arguments'

Assertions look like:

	assert expression ;
	assert expression : msg ;

See: https://docs.oracle.com/javase/8/docs/technotes/guides/language/assert.html

More Information:
-----------------

See the [Readme.md](../../Readme.md) in the main directory of the Git repository for this project to learn more about SWT development.
